@@ -86,7 +86,7 @@ _pygi_argument_from_g_value(const GValue *value,
             arg.v_double = g_value_get_double (value);
             break;
         case GI_TYPE_TAG_GTYPE:
-            arg.v_long = g_value_get_gtype (value);
+            arg.v_size = g_value_get_gtype (value);
             break;
         case GI_TYPE_TAG_UTF8:
         case GI_TYPE_TAG_FILENAME:
@@ -157,6 +157,8 @@ _pygi_argument_from_g_value(const GValue *value,
         case GI_TYPE_TAG_VOID:
             arg.v_pointer = g_value_get_pointer (value);
             break;
+        default:
+            break;
     }
 
     return arg;
@@ -173,15 +175,16 @@ pyg_value_array_from_pyobject(GValue *value,
                               PyObject *obj,
                               const GParamSpecValueArray *pspec)
 {
-    int len;
+    Py_ssize_t seq_len;
     GValueArray *value_array;
-    int i;
+    guint len, i;
 
-    len = PySequence_Length(obj);
-    if (len == -1) {
+    seq_len = PySequence_Length(obj);
+    if (seq_len == -1) {
         PyErr_Clear();
         return -1;
     }
+    len = (guint)seq_len;
 
     if (pspec && pspec->fixed_n_elements > 0 && len != pspec->fixed_n_elements)
         return -1;
@@ -383,8 +386,17 @@ pyg_value_from_pyobject_with_error(GValue *value, PyObject *obj)
         g_value_set_boolean(value, PyObject_IsTrue(obj));
         break;
     case G_TYPE_INT:
-        g_value_set_int(value, PYGLIB_PyLong_AsLong(obj));
+    {
+        glong val = PYGLIB_PyLong_AsLong(obj);
+        if (val == -1 && PyErr_Occurred ())
+            return -1;
+        if (val > G_MAXINT || val < G_MININT) {
+            PyErr_SetString(PyExc_OverflowError, "out of range for int property");
+            return -1;
+        }
+        g_value_set_int(value, (gint)val);
         break;
+    }
     case G_TYPE_UINT:
     {
         if (PYGLIB_PyLong_Check(obj)) {
@@ -567,7 +579,7 @@ pyg_value_from_pyobject_with_error(GValue *value, PyObject *obj)
         break;
     }
     case G_TYPE_PARAM:
-        /* we need to support both the wrapped _gobject.GParamSpec and the GI
+        /* we need to support both the wrapped _gi.GParamSpec and the GI
          * GObject.ParamSpec */
         if (G_IS_PARAM_SPEC (pygobject_get (obj)))
             g_value_set_param(value, G_PARAM_SPEC (pygobject_get (obj)));
